var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
/********************************************************************************
 * Copyright (c) 2019-2020 EclipseSource and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0, or the MIT License which is
 * available at https://opensource.org/licenses/MIT.
 *
 * SPDX-License-Identifier: EPL-2.0 OR MIT
 ********************************************************************************/
import { Actions, jsonformsReducer } from '@jsonforms/core';
import { JsonFormsDispatch, JsonFormsReduxContext } from '@jsonforms/react';
import { registerStyles, stylingReducer, vanillaCells, vanillaRenderers, vanillaStyles } from '@jsonforms/vanilla-renderers';
import { Emitter } from '@theia/core';
import { BaseWidget } from '@theia/core/lib/browser';
import { inject, injectable } from 'inversify';
import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { Provider } from 'react-redux';
import { combineReducers, createStore } from 'redux';
import { TreeEditor } from './interfaces';
var JSON_FORMS_CONTAINER_CSS_CLASS = 'jsonforms-container';
/**
 * Renders the detail view of the tree editor and binds the selected object's data to a generated form.
 */
var DetailFormWidget = /** @class */ (function (_super) {
    __extends(DetailFormWidget, _super);
    function DetailFormWidget(modelService) {
        var _this = _super.call(this) || this;
        _this.modelService = modelService;
        _this.changeEmitter = new Emitter();
        _this.store = _this.initStore();
        _this.store.dispatch(Actions.init({}, { type: 'string' }));
        _this.toDispose.push(_this.changeEmitter);
        _this.store.subscribe(function () {
            _this.changeEmitter.fire(_this.store.getState().jsonforms.core.data);
        });
        _this.renderEmptyForms();
        return _this;
    }
    Object.defineProperty(DetailFormWidget.prototype, "onChange", {
        get: function () {
            return this.changeEmitter.event;
        },
        enumerable: false,
        configurable: true
    });
    DetailFormWidget.prototype.initStore = function () {
        var initState = {
            jsonforms: {
                cells: vanillaCells,
                renderers: vanillaRenderers,
                styles: this.createStyles(),
                config: {
                    restrict: false,
                    trim: false,
                    showUnfocusedDescription: true,
                    hideRequiredAsterisk: false
                }
            }
        };
        return createStore(combineReducers({ jsonforms: jsonformsReducer({ styles: stylingReducer }) }), initState);
    };
    /** Augments the default vanilla styles with theia-specific styling and returns the result. */
    DetailFormWidget.prototype.createStyles = function () {
        var registerStylesAction = registerStyles([
            {
                name: 'array.button',
                classNames: ['theia-button']
            },
            {
                name: 'array.table.button',
                classNames: ['theia-button']
            },
            {
                name: 'control.input',
                classNames: ['theia-input']
            },
            {
                name: 'control.select',
                classNames: ['theia-select']
            }
        ]);
        return stylingReducer(vanillaStyles, registerStylesAction);
    };
    DetailFormWidget.prototype.setSelection = function (selectedNode) {
        this.selectedNode = selectedNode;
        this.store.dispatch(Actions.init(this.modelService.getDataForNode(this.selectedNode), this.modelService.getSchemaForNode(this.selectedNode), this.modelService.getUiSchemaForNode(this.selectedNode), {
            refParserOptions: {
                dereference: { circular: 'ignore' }
            },
            useDefaults: true
        }));
        this.renderForms();
    };
    DetailFormWidget.prototype.renderForms = function () {
        if (this.selectedNode) {
            ReactDOM.render(React.createElement("div", { className: JSON_FORMS_CONTAINER_CSS_CLASS },
                React.createElement(Provider, { store: this.store },
                    React.createElement(JsonFormsReduxContext, null,
                        React.createElement(JsonFormsDispatch, null)))), this.node);
        }
        else {
            this.renderEmptyForms();
        }
    };
    DetailFormWidget.prototype.renderEmptyForms = function () {
        ReactDOM.render(React.createElement(React.Fragment, null, "Please select an element"), this.node);
    };
    DetailFormWidget.prototype.onUpdateRequest = function (msg) {
        _super.prototype.onUpdateRequest.call(this, msg);
        this.renderForms();
    };
    DetailFormWidget = __decorate([
        injectable(),
        __param(0, inject(TreeEditor.ModelService)),
        __metadata("design:paramtypes", [Object])
    ], DetailFormWidget);
    return DetailFormWidget;
}(BaseWidget));
export { DetailFormWidget };
//# sourceMappingURL=detail-form-widget.js.map