var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { WidgetOpenHandler } from '@theia/core/lib/browser';
import { TreeContextMenu } from './master-tree-widget';
import { generateAddCommands } from './util';
/**
 * Abstract base class for defining custom tree editor contributions.
 * An editor's contribution registers its commands and context menus.
 * Furthermore, it defines which URIs the editor can handle and may configure
 * the widget with additional options (see WidgetOpenHandler).
 */
var BaseTreeEditorContribution = /** @class */ (function (_super) {
    __extends(BaseTreeEditorContribution, _super);
    function BaseTreeEditorContribution(editorId, modelService, labelProvider) {
        var _this = _super.call(this) || this;
        _this.editorId = editorId;
        _this.modelService = modelService;
        _this.labelProvider = labelProvider;
        return _this;
    }
    /**
     * @returns maps property names to type identifiers to their corresponding add command
     */
    BaseTreeEditorContribution.prototype.getCommandMap = function () {
        if (!this.commandMap) {
            this.commandMap = generateAddCommands(this.modelService);
        }
        return this.commandMap;
    };
    BaseTreeEditorContribution.prototype.registerCommands = function (commands) {
        var _this = this;
        this.getCommandMap().forEach(function (value, property, _map) {
            value.forEach(function (command, type) { return commands.registerCommand(command, new AddCommandHandler(property, type, _this.modelService)); });
        });
    };
    BaseTreeEditorContribution.prototype.registerMenus = function (menus) {
        var _this = this;
        this.getCommandMap().forEach(function (value, _property, _map) {
            value.forEach(function (command, type) {
                var iconInfo = {
                    _id: 'theia-tree-editor-command-icon-info',
                    editorId: _this.editorId,
                    type: type
                };
                menus.registerMenuAction(TreeContextMenu.ADD_MENU, {
                    commandId: command.id,
                    label: command.label,
                    icon: _this.labelProvider.getIcon(iconInfo)
                });
            });
        });
    };
    return BaseTreeEditorContribution;
}(WidgetOpenHandler));
export { BaseTreeEditorContribution };
var AddCommandHandler = /** @class */ (function () {
    function AddCommandHandler(property, type, modelService) {
        this.property = property;
        this.type = type;
        this.modelService = modelService;
    }
    AddCommandHandler.prototype.execute = function (treeAnchor) {
        treeAnchor.onClick(this.property, this.type);
    };
    AddCommandHandler.prototype.isVisible = function (treeAnchor) {
        if (!treeAnchor) {
            return false;
        }
        // Check whether the node object's type can contain children of this command's type.
        return this.modelService.getChildrenMapping().get(treeAnchor.node.jsonforms.type)
            .map(function (desc) { return desc.children; })
            .reduce(function (acc, val) { return acc.concat(val); }, [])
            .reduce(function (acc, val) { return acc.add(val); }, new Set())
            .has(this.type);
    };
    return AddCommandHandler;
}());
//# sourceMappingURL=tree-editor-contribution.js.map