var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { BaseWidget, SplitPanel, Widget } from '@theia/core/lib/browser';
import { Emitter, ILogger } from '@theia/core/lib/common';
import { WorkspaceService } from '@theia/workspace/lib/browser/workspace-service';
import { injectable, postConstruct } from 'inversify';
import { debounce, isEqual } from 'lodash';
import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { DetailFormWidget } from './detail-form-widget';
import { MasterTreeWidget } from './master-tree-widget';
var BaseTreeEditorWidget = /** @class */ (function (_super) {
    __extends(BaseTreeEditorWidget, _super);
    function BaseTreeEditorWidget(treeWidget, formWidget, workspaceService, logger, widgetId) {
        var _this = _super.call(this) || this;
        _this.treeWidget = treeWidget;
        _this.formWidget = formWidget;
        _this.workspaceService = workspaceService;
        _this.logger = logger;
        _this.widgetId = widgetId;
        _this.dirty = false;
        _this.onDirtyChangedEmitter = new Emitter();
        _this.id = widgetId;
        _this.splitPanel = new SplitPanel();
        _this.addClass(BaseTreeEditorWidget_1.Styles.EDITOR);
        _this.splitPanel.addClass(BaseTreeEditorWidget_1.Styles.SASH);
        _this.treeWidget.addClass(BaseTreeEditorWidget_1.Styles.TREE);
        _this.formWidget.addClass(BaseTreeEditorWidget_1.Styles.FORM);
        _this.formWidget.onChange(debounce(function (data) {
            if (!_this.selectedNode ||
                !_this.selectedNode.jsonforms ||
                isEqual(_this.selectedNode.jsonforms.data, data)) {
                return;
            }
            _this.handleFormUpdate(data, _this.selectedNode);
        }, 250));
        _this.toDispose.push(_this.treeWidget.onSelectionChange(function (ev) { return _this.treeSelectionChanged(ev); }));
        _this.toDispose.push(_this.treeWidget.onDelete(function (node) { return _this.deleteNode(node); }));
        _this.toDispose.push(_this.treeWidget.onAdd(function (addProp) { return _this.addNode(addProp); }));
        _this.toDispose.push(_this.onDirtyChangedEmitter);
        return _this;
    }
    BaseTreeEditorWidget_1 = BaseTreeEditorWidget;
    Object.defineProperty(BaseTreeEditorWidget.prototype, "onDirtyChanged", {
        get: function () {
            return this.onDirtyChangedEmitter.event;
        },
        enumerable: false,
        configurable: true
    });
    BaseTreeEditorWidget.prototype.init = function () {
        this.configureTitle(this.title);
    };
    BaseTreeEditorWidget.prototype.onResize = function (_msg) {
        if (this.splitPanel) {
            this.splitPanel.update();
        }
    };
    BaseTreeEditorWidget.prototype.renderError = function (errorMessage) {
        ReactDOM.render(React.createElement(React.Fragment, null, errorMessage), this.formWidget.node);
    };
    BaseTreeEditorWidget.prototype.treeSelectionChanged = function (selectedNodes) {
        if (selectedNodes.length === 0) {
            this.selectedNode = undefined;
        }
        else {
            this.selectedNode = selectedNodes[0];
            this.formWidget.setSelection(this.selectedNode);
        }
        this.update();
    };
    /**
     * Sets the dirty state of this editor and notify listeners subscribed to the dirty state.
     *
     * @param dirty true if the editor is dirty
     */
    BaseTreeEditorWidget.prototype.setDirty = function (dirty) {
        if (this.dirty !== dirty) {
            this.dirty = dirty;
            this.onDirtyChangedEmitter.fire();
        }
    };
    BaseTreeEditorWidget.prototype.onAfterAttach = function (msg) {
        this.splitPanel.addWidget(this.treeWidget);
        this.splitPanel.addWidget(this.formWidget);
        this.splitPanel.setRelativeSizes([1, 4]);
        Widget.attach(this.splitPanel, this.node);
        this.treeWidget.activate();
        _super.prototype.onAfterAttach.call(this, msg);
    };
    BaseTreeEditorWidget.prototype.onActivateRequest = function () {
        if (this.splitPanel) {
            this.splitPanel.node.focus();
        }
    };
    BaseTreeEditorWidget.prototype.save = function () {
        // do nothing by default
    };
    var BaseTreeEditorWidget_1;
    __decorate([
        postConstruct(),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], BaseTreeEditorWidget.prototype, "init", null);
    BaseTreeEditorWidget = BaseTreeEditorWidget_1 = __decorate([
        injectable(),
        __metadata("design:paramtypes", [MasterTreeWidget,
            DetailFormWidget,
            WorkspaceService, Object, String])
    ], BaseTreeEditorWidget);
    return BaseTreeEditorWidget;
}(BaseWidget));
export { BaseTreeEditorWidget };
// eslint-disable-next-line no-redeclare
(function (BaseTreeEditorWidget) {
    BaseTreeEditorWidget.WIDGET_LABEL = 'Theia Tree Editor';
    var Styles;
    (function (Styles) {
        Styles.EDITOR = 'theia-tree-editor';
        Styles.TREE = 'theia-tree-editor-tree';
        Styles.FORM = 'theia-tree-editor-form';
        Styles.SASH = 'theia-tree-editor-sash';
    })(Styles = BaseTreeEditorWidget.Styles || (BaseTreeEditorWidget.Styles = {}));
})(BaseTreeEditorWidget || (BaseTreeEditorWidget = {}));
//# sourceMappingURL=tree-editor-widget.js.map