var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import { createTreeContainer, defaultTreeProps, TreeProps, TreeWidget as TheiaTreeWidget } from '@theia/core/lib/browser/tree';
import { DetailFormWidget } from './detail-form-widget';
import { TreeEditor } from './interfaces';
import { MasterTreeWidget, TreeContextMenu } from './master-tree-widget';
export var TREE_PROPS = __assign(__assign({}, defaultTreeProps), { contextMenuPath: TreeContextMenu.CONTEXT_MENU, multiSelect: false, search: false });
function createTreeWidget(parent) {
    var treeContainer = createTreeContainer(parent);
    treeContainer.unbind(TheiaTreeWidget);
    treeContainer.bind(MasterTreeWidget).toSelf();
    treeContainer.rebind(TreeProps).toConstantValue(TREE_PROPS);
    return treeContainer.get(MasterTreeWidget);
}
/**
 * Creates a new inversify container to create tree editor widgets using the given customizations.
 * If further services are needed than the given ones, these must either be bound in the parent container
 * or to the returned container before a tree editor widget is requested.
 *
 * Note that this method does not create a singletion tree editor but returns a new instance whenever an instace is requested.
 *
 * @param parent The parent inversify container
 * @param treeEditorWidget The concrete tree editor widget to create
 * @param modelService The tree editor's model service
 * @param nodeFactory The tree editor's node factory
 */
export function createBasicTreeContainter(parent, treeEditorWidget, modelService, nodeFactory) {
    var container = parent.createChild();
    container.bind(TreeEditor.ModelService).to(modelService);
    container.bind(TreeEditor.NodeFactory).to(nodeFactory);
    container.bind(DetailFormWidget).toSelf();
    container.bind(MasterTreeWidget).toDynamicValue(function (context) { return createTreeWidget(context.container); });
    container.bind(treeEditorWidget).toSelf();
    return container;
}
/**
 * Creates a new map based on the model service's children mapping.
 * The created map maps from property name to a new Map.
 * The inner map maps from type identifier to the command used to create a new instance of the type.
 *
 * Basically, this creates add commands for all types that can be created in properties, grouped by property name.
 *
 * Important: Just because an object has a property of a name in the returned mapping,
 * this does not mean the type can be created. To see if a command can be used to create an object's child,
 * the returned mapping needs to be cross-referenced with the model service's children mapping again.
 *
 * @param modelService The tree editor's model service
 */
export function generateAddCommands(modelService) {
    var creatableTypes = Array.from(modelService.getChildrenMapping(), function (_a) {
        var _b = __read(_a, 2), _key = _b[0], value = _b[1];
        return value;
    })
        // get flat array of child descriptors
        .reduce(function (acc, val) { return acc.concat(val); }, [])
        // unify by adding to set
        .reduce(function (acc, val) { return acc.add(val); }, new Set());
    // Create a command for every type which can be added to at least one model object
    var commandMap = new Map();
    Array.from(creatableTypes).forEach(function (desc) {
        var classCommandMap = new Map();
        desc.children.forEach(function (type) {
            var name = modelService.getNameForType(type);
            var command = {
                id: 'json-forms-tree.add.' + name,
                label: name
            };
            classCommandMap.set(type, command);
        });
        commandMap.set(desc.property, classCommandMap);
    });
    return commandMap;
}
//# sourceMappingURL=util.js.map